@@ -11,12 +11,12 @@ use config::{
     get_listeners, key_to_string, run_key, run_key_before, Assistant, Config, PLUGIN_BOOTSTRAP,
     PLUGIN_MANAGER, PLUGIN_NETWORKING, PLUGIN_RUN,
 };
-use crossterm::event::Event as CEvent;
+use crossterm::event::{Event as CEvent, KeyEvent, KeyEventKind};
 use editor::{Editor, FileTypes};
 use error::{OxError, Result};
 use kaolinite::event::{Error as KError, Event};
 use kaolinite::searching::Searcher;
-use kaolinite::utils::file_or_dir;
+use kaolinite::utils::{file_or_dir, get_cwd};
 use kaolinite::Loc;
 use mlua::Error::{RuntimeError, SyntaxError};
 use mlua::{FromLua, Lua, Value};
@@ -96,7 +96,7 @@ fn run(cli: &CommandLineInterface) -> Result<()> {
     editor.borrow_mut().config.document.borrow_mut().file_types = file_types;
 
     // Open files user has asked to open
-    let cwd = std::env::current_dir()?;
+    let cwd = get_cwd().unwrap_or(".".to_string());
     for (c, file) in cli.to_open.iter().enumerate() {
         // Reset cwd
         let _ = std::env::set_current_dir(&cwd);
@@ -161,32 +161,55 @@ fn run(cli: &CommandLineInterface) -> Result<()> {
     // Run the editor and handle errors if applicable
     editor.borrow().update_cwd();
     editor.borrow_mut().init()?;
+    let mut event;
     while editor.borrow().active {
         // Render and wait for event
         editor.borrow_mut().render(&lua)?;
-
-        // While waiting for an event to come along, service the task manager
-        while let Ok(false) = crossterm::event::poll(std::time::Duration::from_millis(100)) {
-            let exec = editor
-                .borrow_mut()
-                .config
-                .task_manager
-                .lock()
-                .unwrap()
-                .execution_list();
-            for task in exec {
-                if let Ok(target) = lua.globals().get::<_, mlua::Function>(task.clone()) {
-                    // Run the code
-                    handle_lua_error("task", target.call(()), &mut editor.borrow_mut().feedback);
-                } else {
-                    editor.borrow_mut().feedback =
-                        Feedback::Warning(format!("Function '{task}' was not found"));
+        // Keep requesting events until a valid one is found
+        loop {
+            // While waiting for an event to come along, service the task manager
+            while let Ok(false) = crossterm::event::poll(std::time::Duration::from_millis(100)) {
+                let exec = editor
+                    .borrow_mut()
+                    .config
+                    .task_manager
+                    .lock()
+                    .unwrap()
+                    .execution_list();
+                for task in exec {
+                    if let Ok(target) = lua.globals().get::<_, mlua::Function>(task.clone()) {
+                        // Run the code
+                        handle_lua_error(
+                            "task",
+                            target.call(()),
+                            &mut editor.borrow_mut().feedback,
+                        );
+                    } else {
+                        editor.borrow_mut().feedback =
+                            Feedback::Warning(format!("Function '{task}' was not found"));
+                    }
                 }
             }
+
+            // Read the event
+            event = crossterm::event::read()?;
+
+            // Block certain events from passing through
+            match event {
+                // Key release events cause duplicate and initial key press events which should be ignored
+                CEvent::Key(KeyEvent {
+                    kind: KeyEventKind::Release,
+                    ..
+                }) => (),
+                _ => break,
+            }
         }
 
-        let event = crossterm::event::read()?;
-        editor.borrow_mut().feedback = Feedback::None;
+        // Clear screen of temporary items (expect on resize event)
+        if !matches!(event, CEvent::Resize(_, _)) {
+            editor.borrow_mut().greet = false;
+            editor.borrow_mut().feedback = Feedback::None;
+        }
 
         // Handle plug-in before key press mappings
         if let CEvent::Key(key) = event {
@@ -234,7 +257,6 @@ fn run(cli: &CommandLineInterface) -> Result<()> {
         }
 
         editor.borrow_mut().update_highlighter();
-        editor.borrow_mut().greet = false;
 
         // Check for any commands to run
         let command = editor.borrow().command.clone();
@@ -327,7 +349,7 @@ fn handle_file_opening(editor: &Rc<RefCell<Editor>>, result: Result<()>, name: &
     }
     match result {
         Ok(()) => (),
-        Err(OxError::AlreadyOpen(_)) => {
+        Err(OxError::AlreadyOpen { .. }) => {
             let len = editor.borrow().files.len().saturating_sub(1);
             editor.borrow_mut().ptr = len;
         }
